@@ -1,6 +1,6 @@
 import hashlib
 import random
-from src.django_random_user_hash.user import User
+from .user import User
 
 def gen_sha1(user: User,version: int) -> str:
     random.seed(a=user.gen_seed_value(),version=version)
@@ -9,5 +9,4 @@ def gen_sha1(user: User,version: int) -> str:
     hash_str = ""
     for o in order:
         hash_str += attrs[o]
-    print(hash_str)
     return hashlib.sha1(bytes(hash_str,'utf-8')).hexdigest()
\ No newline at end of file
